# API Reference

::: naptan.naptan
    handler: python
    options:
      docstring_style: google
      members_order: source
      show_source: false
      show_signature: true
      separate_signature: false
      show_root_toc_entry: false
      show_category_heading: false
      docstring_section_style: table
      filters:
        - "!^APIError"
        - "!^_[^_]"